@@ -313,6 +313,8 @@ snap_to_app (GsPlugin *plugin, SnapdSnap *snap)
 	g_autofree gchar *unique_id = NULL;
 	GsApp *cached_app;
 	g_autoptr(GsApp) app = NULL;
+	SnapdConfinement confinement;
+	GEnumClass *enum_class;
 
 	switch (snapd_snap_get_snap_type (snap)) {
 	case SNAPD_SNAP_TYPE_APP:
@@ -344,7 +346,13 @@ snap_to_app (GsPlugin *plugin, SnapdSnap *snap)
 		gs_app_add_quirk (app, AS_APP_QUIRK_NOT_LAUNCHABLE);
 	if (gs_plugin_check_distro_id (plugin, "ubuntu"))
 		gs_app_add_quirk (app, AS_APP_QUIRK_PROVENANCE);
-	if (priv->system_confinement == SNAPD_SYSTEM_CONFINEMENT_STRICT && snapd_snap_get_confinement (snap) == SNAPD_CONFINEMENT_STRICT)
+
+	confinement = snapd_snap_get_confinement (snap);
+	enum_class = g_type_class_ref (SNAPD_TYPE_CONFINEMENT);
+	gs_app_set_metadata (app, "snap::confinement", g_enum_get_value (enum_class, confinement)->value_nick);
+	g_type_class_unref (enum_class);
+
+	if (priv->system_confinement == SNAPD_SYSTEM_CONFINEMENT_STRICT && confinement == SNAPD_CONFINEMENT_STRICT)
 		gs_app_add_kudo (app, GS_APP_KUDO_SANDBOXED);
 
 	return g_steal_pointer (&app);
@@ -438,7 +446,7 @@ gs_plugin_add_featured (GsPlugin *plugin,
 	snap = snaps->pdata[0];
 	app = snap_to_app (plugin, snap);
 
-	/* if has a sceenshot called 'banner.png' or 'banner-icon.png' then use them for the banner */
+	/* if has a screenshot called 'banner.png' or 'banner-icon.png' then use them for the banner */
 	screenshots = snapd_snap_get_screenshots (snap);
 	for (i = 0; i < screenshots->len; i++) {
 		SnapdScreenshot *screenshot = screenshots->pdata[i];
@@ -568,7 +576,7 @@ static gboolean
 load_icon (GsPlugin *plugin, SnapdClient *client, GsApp *app, const gchar *icon_url, GCancellable *cancellable, GError **error)
 {
 	/* icon is either loaded from snapd or from a URL */
-	if (g_str_has_prefix (icon_url, "/")) {
+	if (icon_url != NULL && g_str_has_prefix (icon_url, "/")) {
 		g_autoptr(SnapdIcon) icon = NULL;
 
 		icon = snapd_client_get_icon_sync (client, gs_app_get_id (app), cancellable, error);
@@ -698,6 +706,8 @@ gs_plugin_refine_app (GsPlugin *plugin,
 	if (local_snap != NULL) {
 		const gchar *name;
 		g_autofree gchar *description = NULL;
+		g_autofree gchar *version = NULL;
+
 		if (gs_app_get_state (app) == AS_APP_STATE_UNKNOWN)
 			gs_app_set_state (app, AS_APP_STATE_INSTALLED);
 		name = snapd_snap_get_title (local_snap);
@@ -709,7 +719,8 @@ gs_plugin_refine_app (GsPlugin *plugin,
 		if (description != NULL)
 			gs_app_set_description (app, GS_APP_QUALITY_NORMAL, description);
 		gs_app_set_license (app, GS_APP_QUALITY_NORMAL, snapd_snap_get_license (local_snap));
-		gs_app_set_version (app, snapd_snap_get_version (local_snap));
+		version = g_strdup_printf ("%s (%s)", snapd_snap_get_version (local_snap), snapd_snap_get_revision (local_snap));
+		gs_app_set_version (app, version);
 		gs_app_set_size_installed (app, snapd_snap_get_installed_size (local_snap));
 		gs_app_set_install_date (app, g_date_time_to_unix (snapd_snap_get_install_date (local_snap)));
 		gs_app_set_developer_name (app, snapd_snap_get_developer (local_snap));
@@ -739,7 +750,11 @@ gs_plugin_refine_app (GsPlugin *plugin,
 		if (description != NULL)
 			gs_app_set_description (app, GS_APP_QUALITY_NORMAL, description);
 		gs_app_set_license (app, GS_APP_QUALITY_NORMAL, snapd_snap_get_license (store_snap));
-		gs_app_set_version (app, snapd_snap_get_version (store_snap));
+		if (gs_app_get_version (app) == NULL) {
+			g_autofree gchar *version = NULL;
+			version = g_strdup_printf ("%s (%s)", snapd_snap_get_version (store_snap), snapd_snap_get_revision (store_snap));
+			gs_app_set_version (app, version);
+		}
 		gs_app_set_size_download (app, snapd_snap_get_download_size (store_snap));
 		gs_app_set_developer_name (app, snapd_snap_get_developer (store_snap));
 		if (icon_url == NULL) {
@@ -759,7 +774,7 @@ gs_plugin_refine_app (GsPlugin *plugin,
 				g_autoptr(AsScreenshot) ss = NULL;
 				g_autoptr(AsImage) image = NULL;
 
-				/* skip sceenshots used for banner when app is featured */
+				/* skip screenshots used for banner when app is featured */
 				url = snapd_screenshot_get_url (screenshot);
 				filename = g_path_get_basename (url);
 				if (is_banner_image (filename) || is_banner_icon_image (filename))
@@ -816,6 +831,7 @@ gs_plugin_app_install (GsPlugin *plugin,
 		       GError **error)
 {
 	g_autoptr(SnapdClient) client = NULL;
+	SnapdInstallFlags flags = SNAPD_INSTALL_FLAGS_NONE;
 
 	/* We can only install apps we know of */
 	if (g_strcmp0 (gs_app_get_management_plugin (app), "snap") != 0)
@@ -826,7 +842,9 @@ gs_plugin_app_install (GsPlugin *plugin,
 		return FALSE;
 
 	gs_app_set_state (app, AS_APP_STATE_INSTALLING);
-	if (!snapd_client_install2_sync (client, SNAPD_INSTALL_FLAGS_NONE, gs_app_get_id (app), NULL, NULL, progress_cb, app, cancellable, error)) {
+	if (g_strcmp0 (gs_app_get_metadata_item (app, "snap::confinement"), "classic") == 0)
+		flags |= SNAPD_INSTALL_FLAGS_CLASSIC;
+	if (!snapd_client_install2_sync (client, flags, gs_app_get_id (app), NULL, NULL, progress_cb, app, cancellable, error)) {
 		gs_app_set_state_recover (app);
 		snapd_error_convert (error);
 		return FALSE;
@@ -957,12 +975,21 @@ gs_plugin_auth_login (GsPlugin *plugin, GsAuth *auth,
 	g_clear_object (&priv->auth_data);
 	if (priv->snapd_supports_polkit) {
 		g_autoptr(SnapdClient) client = NULL;
+#ifdef SNAPD_GLIB_VERSION_1_26
+		g_autoptr(SnapdUserInformation) user_information = NULL;
+#endif
 
 		client = get_client (plugin, error);
 		if (client == NULL)
 			return FALSE;
 
+#ifdef SNAPD_GLIB_VERSION_1_26
+		user_information = snapd_client_login2_sync (client, gs_auth_get_username (auth), gs_auth_get_password (auth), gs_auth_get_pin (auth), NULL, error);
+		if (user_information != NULL)
+			priv->auth_data = g_object_ref (snapd_user_information_get_auth_data (user_information));
+#else
 		priv->auth_data = snapd_client_login_sync (client, gs_auth_get_username (auth), gs_auth_get_password (auth), gs_auth_get_pin (auth), NULL, error);
+#endif
 	}
 	else
 		priv->auth_data = snapd_login_sync (gs_auth_get_username (auth), gs_auth_get_password (auth), gs_auth_get_pin (auth), NULL, error);
