@@ -239,7 +239,7 @@ get_system_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 		return;
 	}
 
-	/* might be alrady showing, so just withdraw it and re-issue it */
+	/* might be already showing, so just withdraw it and re-issue it */
 	g_application_withdraw_notification (monitor->application, "eol");
 
 	/* do not show when the main window is active */
@@ -316,6 +316,13 @@ static void
 get_updates (GsUpdateMonitor *monitor)
 {
 	g_autoptr(GsPluginJob) plugin_job = NULL;
+
+	/* disabled in gsettings or from a plugin */
+	if (!gs_plugin_loader_get_allow_updates (monitor->plugin_loader)) {
+		g_debug ("not getting updates as not enabled");
+		return;
+	}
+
 	/* NOTE: this doesn't actually do any network access, instead it just
 	 * returns already downloaded-and-depsolved packages */
 	g_debug ("Getting updates");
@@ -336,6 +343,12 @@ get_upgrades (GsUpdateMonitor *monitor)
 {
 	g_autoptr(GsPluginJob) plugin_job = NULL;
 
+	/* disabled in gsettings or from a plugin */
+	if (!gs_plugin_loader_get_allow_updates (monitor->plugin_loader)) {
+		g_debug ("not getting upgrades as not enabled");
+		return;
+	}
+
 	/* NOTE: this doesn't actually do any network access, it relies on the
 	 * AppStream data being up to date, either by the appstream-data
 	 * package being up-to-date, or the metadata being auto-downloaded */
@@ -381,8 +394,7 @@ refresh_cache_finished_cb (GObject *object,
 			g_warning ("failed to refresh the cache: %s", error->message);
 		return;
 	}
-	if (gs_plugin_loader_get_allow_updates (monitor->plugin_loader))
-		get_updates (monitor);
+	get_updates (monitor);
 }
 
 typedef enum {
@@ -762,7 +774,7 @@ allow_updates_notify_cb (GsPluginLoader *plugin_loader,
 {
 	if (gs_plugin_loader_get_allow_updates (plugin_loader)) {
 		/* We restart the updates check here to avoid the user
-		 * pontentially waiting for the hourly check */
+		 * potentially waiting for the hourly check */
 		restart_updates_check (monitor);
 		restart_upgrades_check (monitor);
 	} else {
